netapp_ontap.resources.key_manager_config API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.resources.key_manager_config`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Overview

Retrieves or modifies the key management configuration options. The following operations are supported:

- GET
- PATCH

## Examples

### Retrieving cluster-level key manager configurations

The following example shows how to retrieve cluster-level manager configurations.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import KeyManagerConfig

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = KeyManagerConfig()
        resource.get()
        print(resource)

Try it out

    KeyManagerConfig(
        {
            "_links": {"self": {"href": "/api/security/key-manager-configs"}},
            "health_monitor_policy": {
                "kmip": {"manage_volume_offline": True, "enabled": True},
                "okm": {"manage_volume_offline": True, "enabled": True},
                "aws": {"manage_volume_offline": True, "enabled": True},
                "gcp": {"manage_volume_offline": True, "enabled": True},
                "akv": {"manage_volume_offline": True, "enabled": True},
                "ikp": {"manage_volume_offline": True, "enabled": True},
            },
            "cloud_kms_retry_count": 3,
            "cc_mode_enabled": False,
            "health_monitor_polling_interval": 15,
        }
    )

### Updating the cluster-level key manager configurations

The following example shows how to modify the "health_monitor_polling_interval" and "cloud_kms_retry_count" fields.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import KeyManagerConfig

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = KeyManagerConfig()
        resource.health_monitor_polling_interval = "20"
        resource.cloud_kms_retry_count = "5"
        resource.patch()

### Updating the cluster-level key manager configurations

The following example shows how to modify the "cc_mode" and "passphrase" fields.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import KeyManagerConfig

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = KeyManagerConfig()
        resource.cc_mode_enabled = True
        resource.passphrase = "current_passphrase"
        resource.patch()

### Shows the keystore level health monitor policy

The following example shows how to retrieve the health monitor policies for Amazon Web Services and Google Cloud.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import KeyManagerConfig

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = KeyManagerConfig()
        resource.get(fields="health_monitor_policy.aws,health_monitor_policy.gcp")
        print(resource)

Try it out

    KeyManagerConfig(
        {
            "_links": {"self": {"href": "/api/security/key-manager-configs"}},
            "health_monitor_policy": {
                "aws": {"manage_volume_offline": False, "enabled": False},
                "gcp": {"manage_volume_offline": False, "enabled": False},
            },
        }
    )

### Updates the keytore level health monitor policy

The following example shows how to modify the Amazon Web Services "enabled" field and the Google Cloud "manage_volume_offline" field of the health monitor policy.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import KeyManagerConfig

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = KeyManagerConfig()
        resource.health_monitor_policy = {
            "aws": {"enabled": "false"},
            "gcp": {"manage_volume_offline": "false"},
        }
        resource.patch()

## Classes

`class KeyManagerConfig (*args, **kwargs)`

  Manages the various key manager configuration options.

  Initialize the instance of the resource.

  Any keyword arguments are set on the instance as properties. For example, if the class was named 'MyResource', then this statement would be true:

      MyResource(name='foo').name == 'foo'

  ## Args

  `*args`
    Each positional argument represents a parent key as used in the URL of the object. That is, each value will be used to fill in a segment of the URL which refers to some parent object. The order of these arguments must match the order they are specified in the URL, from left to right.
  `**kwargs`
    each entry will have its key set as an attribute name on the instance and its value will be the value of that attribute.

  ### Ancestors

  - Resource

  ### Methods

  `def get (self, **kwargs) -> NetAppResponse`

    Retrieves key manager configurations. Retrieves the key manager health monitor policy (fields=health_monitor_policy).

    ### Related ONTAP commands

    - `security key-manager config show`
    - `security key-manager health policy show`

    ### Learn more

    - `DOC /security/key-manager-configs`

    Fetch the details of the object from the host.

    Requires the keys to be set (if any). After returning, new or changed properties from the host will be set on the instance.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400 or if not all of the keys required are present and config.STRICT_GET has been set to True.

  `def patch (self, hydrate: bool = False, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, **kwargs) -> NetAppResponse`

    Updates key manager configurations. Updates the key manager health monitor policy.

    ### Related ONTAP commands

    - `security key-manager config modify`
    - `security key-manager health policy modify`

    ### Learn more

    - `DOC /security/key-manager-configs`

    Send the difference in the object's state to the host as a modification request.

    Calculates the difference in the object's state since the last time we interacted with the host and sends this in the request body.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Inherited members

  - `Resource`:
    - `from_dict`
    - `get_collection_url`
    - `get_connection`
    - `instance_location`
    - `path_keys`
    - `poll`
    - `set_connection`
    - `to_dict`
    - `validate_schema`
`class KeyManagerConfigSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the KeyManagerConfig object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `cc_mode_enabled: bool GET PATCH`

    Indicates whether the Common Criteria Mode configuration is enabled.

  `cloud_kms_retry_count: Size GET PATCH`

    Cloud key manager connection retry count. Supported value range of 0-10.

    Example: 3

  `health_monitor_policy: KeyManagerConfigHealthMonitorPolicy GET PATCH`

    Manages the keystore configurations.

  `health_monitor_polling_interval: Size GET PATCH`

    Health Monitor Polling Period, in minutes. Supported value range of 15-30 minutes.

    Example: 20

  `links: SelfLink GET`

    The links field of the key_manager_config.

  `passphrase: str PATCH`

    Current cluster-wide passphrase. This is a required field when setting the cc_mode_enabled field value to true. This is not audited.

    Example: The cluster passphrase of length 64-256 ASCII characters.